STS — boto v2.21.1

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »

# STS

## boto.sts

`boto.sts.` `connect_to_region`(region_name, **kw_params)

  Given a valid region name, return a `boto.sts.connection.STSConnection`.

  Type : | str
  Parameters: | region_name – The name of the region to connect to.
  Return type: | `boto.sts.connection.STSConnection` or `None`
  Returns: | A connection to the given region, or None if an invalid region name is given

`boto.sts.` `regions`()

  Get all available regions for the STS service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo` instances

class `boto.sts.` `STSConnection`(aws_access_key_id=None, aws_secret_access_key=None, is_secure=True, port=None, proxy=None, proxy_port=None, proxy_user=None, proxy_pass=None, debug=0, https_connection_factory=None, region=None, path='/', converter=None, validate_certs=True, anon=False, security_token=None)

  AWS Security Token Service The AWS Security Token Service is a web service that enables you to request temporary, limited-privilege credentials for AWS Identity and Access Management (IAM) users or for users that you authenticate (federated users). This guide provides descriptions of the AWS Security Token Service API.

  For more detailed information about using this service, go to `Using Temporary Security Credentials`_.

  For information about setting up signatures and authorization through the API, go to `Signing AWS API Requests`_ in the AWS General Reference . For general information about the Query API, go to `Making Query Requests`_ in Using IAM . For information about using security tokens with other AWS products, go to `Using Temporary Security Credentials to Access AWS`_ in Using Temporary Security Credentials .

  If you’re new to AWS and need additional technical information about a specific AWS product, you can find the product’s technical documentation at `http://aws.amazon.com/documentation/`_.

  We will refer to Amazon Identity and Access Management using the abbreviated form IAM. All copyrights and legal protections still apply.

  `APIVersion` = '2011-06-15'
  `DefaultRegionEndpoint` = 'sts.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `assume_role`(role_arn, role_session_name, policy=None, duration_seconds=None, external_id=None)

    Returns a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) that you can use to access AWS resources that you might not normally have access to. Typically, you use AssumeRole for cross-account access or federation.

    For cross-account access, imagine that you own multiple accounts and need to access resources in each account. You could create long-term credentials in each account to access those resources. However, managing all those credentials and remembering which one can access which account can be time consuming. Instead, you can create one set of long-term credentials in one account and then use temporary security credentials to access all the other accounts by assuming roles in those accounts. For more information about roles, see `Roles`_ in Using IAM .

    For federation, you can, for example, grant single sign-on access to the AWS Management Console. If you already have an identity and authentication system in your corporate network, you don’t have to recreate user identities in AWS in order to grant those user identities access to AWS. Instead, after a user has been authenticated, you call AssumeRole (and specify the role with the appropriate permissions) to get temporary security credentials for that user. With those temporary security credentials, you construct a sign-in URL that users can use to access the console. For more information, see `Scenarios for Granting Temporary Access`_ in AWS Security Token Service .

    The temporary security credentials are valid for the duration that you specified when calling AssumeRole, which can be from 900 seconds (15 minutes) to 3600 seconds (1 hour). The default is 1 hour.

    The temporary security credentials that are returned from the AssumeRoleWithWebIdentity response have the permissions that are associated with the access policy of the role being assumed and any policies that are associated with the AWS resource being accessed. You can further restrict the permissions of the temporary security credentials by passing a policy in the request. The resulting permissions are an intersection of the role’s access policy and the policy that you passed. These policies and any applicable resource-based policies are evaluated when calls to AWS service APIs are made using the temporary security credentials.

    To assume a role, your AWS account must be trusted by the role. The trust relationship is defined in the role’s trust policy when the IAM role is created. You must also have a policy that allows you to call sts:AssumeRole.

    Important: You cannot call Assumerole by using AWS account credentials; access will be denied. You must use IAM user credentials to call AssumeRole.

    Parameters: | role_arn (string) – The Amazon Resource Name (ARN) of the role that the caller is assuming. role_session_name (string) – An identifier for the assumed role session. The session name is included as part of the AssumedRoleUser. policy (string) – A supplemental policy that is associated with the temporary security credentials from the AssumeRole call. The resulting permissions of the temporary security credentials are an intersection of this policy and the access policy that is associated with the role. Use this policy to further restrict the permissions of the temporary security credentials. duration_seconds (integer) – The duration, in seconds, of the role session. The value can range from 900 seconds (15 minutes) to 3600 seconds (1 hour). By default, the value is set to 3600 seconds. external_id (string) – A unique identifier that is used by third parties to assume a role in their customers’ accounts. For each role that the third party can assume, they should instruct their customers to create a role with the external ID that the third party generated. Each time the third party assumes the role, they must pass the customer’s external ID. The external ID is useful in order to help third parties bind a role to the customer who created it. For more information about the external ID, see `About the External ID`_ in Using Temporary Security Credentials .

  `assume_role_with_saml`(role_arn, principal_arn, saml_assertion, policy=None, duration_seconds=None)

    Returns a set of temporary security credentials for users who have been authenticated via a SAML authentication response. This operation provides a mechanism for tying an enterprise identity store or directory to role-based AWS access without user-specific credentials or configuration.

    The temporary security credentials returned by this operation consist of an access key ID, a secret access key, and a security token. Applications can use these temporary security credentials to sign calls to AWS services. The credentials are valid for the duration that you specified when calling AssumeRoleWithSAML, which can be up to 3600 seconds (1 hour) or until the time specified in the SAML authentication response’s NotOnOrAfter value, whichever is shorter.

    The maximum duration for a session is 1 hour, and the minimum duration is 15 minutes, even if values outside this range are specified.

    Optionally, you can pass an AWS IAM access policy to this operation. The temporary security credentials that are returned by the operation have the permissions that are associated with the access policy of the role being assumed, except for any permissions explicitly denied by the policy you pass. This gives you a way to further restrict the permissions for the federated user. These policies and any applicable resource-based policies are evaluated when calls to AWS are made using the temporary security credentials.

    Before your application can call AssumeRoleWithSAML, you must configure your SAML identity provider (IdP) to issue the claims required by AWS. Additionally, you must use AWS Identity and Access Management (AWS IAM) to create a SAML provider entity in your AWS account that represents your identity provider, and create an AWS IAM role that specifies this SAML provider in its trust policy.

    Calling AssumeRoleWithSAML does not require the use of AWS security credentials. The identity of the caller is validated by using keys in the metadata document that is uploaded for the SAML provider entity for your identity provider.

    For more information, see the following resources:

    - `Creating Temporary Security Credentials for SAML Federation`_ in the Using Temporary Security Credentials guide.
    - `SAML Providers`_ in the Using IAM guide.
    - `Configuring a Relying Party and Claims in the Using IAM guide. `_
    - `Creating a Role for SAML-Based Federation`_ in the Using IAM guide.

    Parameters: | role_arn (string) – The Amazon Resource Name (ARN) of the role that the caller is assuming. principal_arn (string) – The Amazon Resource Name (ARN) of the SAML provider in AWS IAM that describes the IdP. saml_assertion (string) – The base-64 encoded SAML authentication response provided by the IdP.

    For more information, see `Configuring a Relying Party and Adding
      Claims`_ in the Using IAM guide.

    Parameters: | policy (string) –

    An AWS IAM policy in JSON format.

    The temporary security credentials that are returned by this operation
      have the permissions that are associated with the access policy of the role being assumed, except for any permissions explicitly denied by the policy you pass. These policies and any applicable resource-based policies are evaluated when calls to AWS are made using the temporary security credentials.
    The policy must be 2048 bytes or shorter, and its packed size must be
      less than 450 bytes.

    Parameters: | duration_seconds (integer) –

    The duration, in seconds, of the role session. The value can range from
      900 seconds (15 minutes) to 3600 seconds (1 hour). By default, the value is set to 3600 seconds. An expiration can also be specified in the SAML authentication response’s NotOnOrAfter value. The actual expiration time is whichever value is shorter.
    The maximum duration for a session is 1 hour, and the minimum duration
      is 15 minutes, even if values outside this range are specified.
  `assume_role_with_web_identity`(role_arn, role_session_name, web_identity_token, provider_id=None, policy=None, duration_seconds=None)

    Returns a set of temporary security credentials for users who have been authenticated in a mobile or web application with a web identity provider, such as Login with Amazon, Facebook, or Google. AssumeRoleWithWebIdentity is an API call that does not require the use of AWS security credentials. Therefore, you can distribute an application (for example, on mobile devices) that requests temporary security credentials without including long-term AWS credentials in the application or by deploying server-based proxy services that use long-term AWS credentials. For more information, see `Creating a Mobile Application with Third-Party Sign-In`_ in AWS Security Token Service .

    The temporary security credentials consist of an access key ID, a secret access key, and a security token. Applications can use these temporary security credentials to sign calls to AWS service APIs. The credentials are valid for the duration that you specified when calling AssumeRoleWithWebIdentity, which can be from 900 seconds (15 minutes) to 3600 seconds (1 hour). By default, the temporary security credentials are valid for 1 hour.

    The temporary security credentials that are returned from the AssumeRoleWithWebIdentity response have the permissions that are associated with the access policy of the role being assumed. You can further restrict the permissions of the temporary security credentials by passing a policy in the request. The resulting permissions are an intersection of the role’s access policy and the policy that you passed. These policies and any applicable resource-based policies are evaluated when calls to AWS service APIs are made using the temporary security credentials.

    Before your application can call AssumeRoleWithWebIdentity, you must have an identity token from a supported identity provider and create a role that the application can assume. The role that your application assumes must trust the identity provider that is associated with the identity token. In other words, the identity provider must be specified in the role’s trust policy. For more information, see ` Creating Temporary Security Credentials for Mobile Apps Using Third-Party Identity Providers`_.

    Parameters: | role_arn (string) – The Amazon Resource Name (ARN) of the role that the caller is assuming. role_session_name (string) – An identifier for the assumed role session. Typically, you pass the name or identifier that is associated with the user who is using your application. That way, the temporary security credentials that your application will use are associated with that user. This session name is included as part of the ARN and assumed role ID in the AssumedRoleUser response element. web_identity_token (string) – The OAuth 2.0 access token or OpenID Connect ID token that is provided by the identity provider. Your application must get this token by authenticating the user who is using your application with a web identity provider before the application makes an AssumeRoleWithWebIdentity call. provider_id (string) – Specify this value only for OAuth access tokens. Do not specify this value for OpenID Connect ID tokens, such as accounts.google.com. This is the fully-qualified host component of the domain name of the identity provider. Do not include URL schemes and port numbers. Currently, www.amazon.com and graph.facebook.com are supported. policy (string) – A supplemental policy that is associated with the temporary security credentials from the AssumeRoleWithWebIdentity call. The resulting permissions of the temporary security credentials are an intersection of this policy and the access policy that is associated with the role. Use this policy to further restrict the permissions of the temporary security credentials. duration_seconds (integer) – The duration, in seconds, of the role session. The value can range from 900 seconds (15 minutes) to 3600 seconds (1 hour). By default, the value is set to 3600 seconds.

  `decode_authorization_message`(encoded_message)

    Decodes additional information about the authorization status of a request from an encoded message returned in response to an AWS request.

    For example, if a user is not authorized to perform an action that he or she has requested, the request returns a Client.UnauthorizedOperation response (an HTTP 403 response). Some AWS actions additionally return an encoded message that can provide details about this authorization failure. Only certain AWS actions return an encoded authorization message. The documentation for an individual action indicates whether that action returns an encoded message in addition to returning an HTTP code. The message is encoded because the details of the authorization status can constitute privileged information that the user who requested the action should not see. To decode an authorization status message, a user must be granted permissions via an IAM policy to request the DecodeAuthorizationMessage ( sts:DecodeAuthorizationMessage) action.

    The decoded message includes the following type of information:

    - Whether the request was denied due to an explicit deny or due to the absence of an explicit allow. For more information, see `Determining Whether a Request is Allowed or Denied`_ in Using IAM .
    - The principal who made the request.
    - The requested action.
    - The requested resource.
    - The values of condition keys in the context of the user’s request.

    Parameters: | encoded_message (string) – The encoded message that was returned with the response.

  `get_federation_token`(name, duration=None, policy=None)

    Returns a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) for a federated user. A typical use is in a proxy application that is getting temporary security credentials on behalf of distributed applications inside a corporate network. Because you must call the GetFederationToken action using the long- term security credentials of an IAM user, this call is appropriate in contexts where those credentials can be safely stored, usually in a server-based application.

    Note: Do not use this call in mobile applications or client-based web applications that directly get temporary security credentials. For those types of applications, use AssumeRoleWithWebIdentity.

    The GetFederationToken action must be called by using the long-term AWS security credentials of the AWS account or an IAM user. Credentials that are created by IAM users are valid for the specified duration, between 900 seconds (15 minutes) and 129600 seconds (36 hours); credentials that are created by using account credentials have a maximum duration of 3600 seconds (1 hour).

    The permissions that are granted to the federated user are the intersection of the policy that is passed with the GetFederationToken request and policies that are associated with of the entity making the GetFederationToken call.

    For more information about how permissions work, see `Controlling Permissions in Temporary Credentials`_ in Using Temporary Security Credentials . For information about using GetFederationToken to create temporary security credentials, see `Creating Temporary Credentials to Enable Access for Federated Users`_ in Using Temporary Security Credentials .

    Parameters: | name (string) – The name of the federated user. The name is used as an identifier for the temporary security credentials (such as Bob). For example, you can reference the federated user name in a resource-based policy, such as in an Amazon S3 bucket policy. policy (string) – A policy that specifies the permissions that are granted to the federated user. By default, federated users have no permissions; they do not inherit any from the IAM user. When you specify a policy, the federated user’s permissions are intersection of the specified policy and the IAM user’s policy. If you don’t specify a policy, federated users can only access AWS resources that explicitly allow those federated users in a resource policy, such as in an Amazon S3 bucket policy. duration (integer) – The duration, in seconds, that the session should last. Acceptable durations for federation sessions range from 900 seconds (15 minutes) to 129600 seconds (36 hours), with 43200 seconds (12 hours) as the default. Sessions for AWS account owners are restricted to a maximum of 3600 seconds (one hour). If the duration is longer than one hour, the session for AWS account owners defaults to one hour.

  `get_session_token`(duration=None, force_new=False, mfa_serial_number=None, mfa_token=None)

    Return a valid session token. Because retrieving new tokens from the Secure Token Service is a fairly heavyweight operation this module caches previously retrieved tokens and returns them when appropriate. Each token is cached with a key consisting of the region name of the STS endpoint concatenated with the requesting user’s access id. If there is a token in the cache meeting with this key, the session expiration is checked to make sure it is still valid and if so, the cached token is returned. Otherwise, a new session token is requested from STS and it is placed into the cache and returned.

    Parameters: | duration (int) – The number of seconds the credentials should remain valid. force_new (bool) – If this parameter is True, a new session token will be retrieved from the Secure Token Service regardless of whether there is a valid cached token or not. mfa_serial_number (str) – The serial number of an MFA device. If this is provided and if the mfa_passcode provided is valid, the temporary session token will be authorized with to perform operations requiring the MFA device authentication. mfa_token (str) – The 6 digit token associated with the MFA device.

## boto.sts.credentials

class `boto.sts.credentials.` `AssumedRole`(connection=None, credentials=None, user=None)

  Variables: | user – The assumed role user. credentials – A Credentials object containing the credentials.

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.sts.credentials.` `Credentials`(parent=None)

  Variables: | access_key – The AccessKeyID. secret_key – The SecretAccessKey. session_token – The session token that must be passed with requests to use the temporary credentials expiration – The timestamp for when the credentials will expire

  `endElement`(name, value, connection)
  classmethod `from_json`(json_doc)

    Create and return a new Session Token based on the contents of a JSON document.

    Parameters: | json_doc (str) – A string containing a JSON document with a previously saved Credentials object.

  `is_expired`(time_offset_seconds=0)

    Checks to see if the Session Token is expired or not. By default it will check to see if the Session Token is expired as of the moment the method is called. However, you can supply an optional parameter which is the number of seconds of offset into the future for the check. For example, if you supply a value of 5, this method will return a True if the Session Token will be expired 5 seconds from this moment.

    Parameters: | time_offset_seconds (int) – The number of seconds into the future to test the Session Token for expiration.

  classmethod `load`(file_path)

    Create and return a new Session Token based on the contents of a previously saved JSON-format file.

    Parameters: | file_path (str) – The fully qualified path to the JSON-format file containing the previously saved Session Token information.

  `save`(file_path)

    Persist a Session Token to a file in JSON format.

    Parameters: | path (str) – The fully qualified path to the file where the the Session Token data should be written. Any previous data in the file will be overwritten. To help protect the credentials contained in the file, the permissions of the file will be set to readable/writable by owner only.

  `startElement`(name, attrs, connection)
  `to_dict`()

    Return a Python dict containing the important information about this Session Token.

class `boto.sts.credentials.` `DecodeAuthorizationMessage`(request_id=None, decoded_message=None)

  Variables: | request_id – The request ID. decoded_message – The decoded authorization message (may be JSON).

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.sts.credentials.` `FederationToken`(parent=None)

  Variables: | credentials – A Credentials object containing the credentials. federated_user_arn – ARN specifying federated user using credentials. federated_user_id – The ID of the federated user using credentials. packed_policy_size – A percentage value indicating the size of the policy in packed form

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.sts.credentials.` `User`(arn=None, assume_role_id=None)

  Variables: | arn – The arn of the user assuming the role. assume_role_id – The identifier of the assumed role.

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »